<template>
  <div class="app-container">
    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button type="primary" plain icon="el-icon-plus" :size="ELsize" @click="handleAdd">新增</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" row-key="categoryId"
      :tree-props="{ children: 'childrenList', hasChildren: 'hasChildren' }" :data="list" default-expand-all
      :border="TableBorder" :size="ELTableSize">
      <el-table-column type="index" width="55" label="序号" align="center">
        <template slot-scope="{$index}">
          {{ $getTableIndex(queryParams, $index + 1) }}
        </template>
      </el-table-column>
      <el-table-column label="分类名称" align="center" prop="categoryName" />
      <el-table-column label="分类图标" align="center" prop="image">
        <template slot-scope="scope">
          <el-image v-if="scope.row.categoryIcon" style="width: 50px; height: 50px" :src="scope.row.categoryIcon"
            :preview-src-list="scope.row.categoryIcon ? [scope.row.categoryIcon] : []
              "></el-image>
          <span v-else>--</span>
        </template>
      </el-table-column>
      <el-table-column label="分类描述" align="center" prop="categoryDescription" show-overflow-tooltip>
        <template slot-scope="scope">
          <span>{{ scope.row.categoryDescription | TableItemEmpty }}</span>
        </template>
      </el-table-column>
      <el-table-column label="排序" align="center" prop="categorySort" />
      <el-table-column label="上架状态" align="center" prop="shelvedStatus">
        <template slot-scope="{ row }">
          <el-tag type="success" v-if="row.shelvedStatus">上架</el-tag>
          <el-tag type="danger" v-if="!row.shelvedStatus">下架</el-tag>
        </template>
      </el-table-column>
      <el-table-column label="创建时间" align="center" prop="createTime" width="180">
        <template slot-scope="scope">
          <span>{{
            parseTime(scope.row.createTime, "{y}-{m}-{d} {h}:{i}")
          }}</span>
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width" width="180">
        <template slot-scope="scope">
          <el-button :size="ELTableSize" type="text" icon="el-icon-edit" @click="handleUpdate(scope.row)">修改</el-button>
          <el-button :size="ELTableSize" type="text" icon="el-icon-delete"
            @click="handleDelete(scope.row)">删除</el-button>
          <el-button :size="ELTableSize" type="text" @click="setStatus(scope.row)">{{
            scope.row.shelvedStatus ? "下架" : "上架"
          }}</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination v-show="total > 0" :total="total" :page.sync="queryParams.pageNum" :limit.sync="queryParams.pageSize"
      @pagination="getList" />

    <!-- 添加或修改测试单表对话框 -->
    <el-drawer :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="120px" :size="ELsize">
        <el-form-item label="分类名称" prop="categoryName">
          <el-input v-model="form.categoryName" placeholder="请输入分类名称" />
        </el-form-item>
        <!-- <el-form-item label="上级分类" prop="parentId">
          <el-select
            v-model="form.parentId"
            placeholder="请选择上级分类"
            clearable
            style="width: 100%"
          >
            <el-option
              v-for="(v, i) in topList"
              :key="i"
              :label="v.categoryName"
              :value="v.categoryId"
            />
          </el-select>
        </el-form-item> -->
        <el-form-item label="广告图片" prop="categoryIcon">
          <imageUpload v-model="form.categoryIcon" :limit="1" />
        </el-form-item>
        <el-form-item label="分类描述" prop="categoryDescription">
          <el-input type="textarea" :rows="2" placeholder="请输入分类描述" v-model="form.categoryDescription">
          </el-input>
        </el-form-item>
        <el-form-item label="排序" prop="orderIndex">
          <el-input-number v-model="form.categorySort" :min="1" label="排序" :precision="0"></el-input-number>
        </el-form-item>
        <el-form-item label="上架状态" prop="status">
          <el-select v-model="form.shelvedStatus" placeholder="请选择上架状态" clearable style="width: 100%">
            <el-option label="上架" :value="true" />
            <el-option label="下架" :value="false" />
          </el-select>
        </el-form-item>
      </el-form>
      <div class="demo-drawer__footer">
        <el-button :loading="buttonLoading" type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-drawer>
  </div>
</template>

<script>
import {
  productCategoryAdd,
  productCategoryEdit,
  productCategoryTree,
  productCategoryTops,
  productCategoryInfo,
  productCategoryShelved,
  productCategoryDel,
  productCategoryPage,
} from "@/api/goodsClassify.js";
export default {
  data() {
    return {
      //按钮loading
      buttonLoading: false,
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 测试单表表格数据
      list: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        categoryName: undefined,
        shelvedStatus: undefined,
      },
      // 表单参数
      form: {
        categorySort: 1,
        parentId: null,
        categoryName: null,
        categoryIcon: null,
        shelvedStatus: true,
      },
      // 表单校验
      rules: {
        categoryName: [
          { required: true, message: "请输入分类名称", trigger: "blur" },
        ],
        // categoryIcon: [
        //   { required: true, message: "请上传分类图标", trigger: "blur" },
        // ],
        // categoryDescription: [
        //   { required: true, message: "请输入分类描述", trigger: "blur" },
        // ],
        categorySort: [
          { required: true, message: "请输入排序号", trigger: "change" },
        ],
        shelvedStatus: [
          { required: true, message: "请选择上架状态", trigger: "blur" },
        ],
      },
      topList: [],
    };
  },
  created() {
    this.getList();
    this.getTopList();
  },
  methods: {
    /** 查询测试单表列表 */
    getList() {
      this.loading = true;
      productCategoryPage(this.queryParams).then((res) => {
        // this.list = this.handleTree(response.data, "categoryId");
        // console.log(this.list);
        if (res.code == 200) {
          this.list = res.rows;
          this.total = res.total;
          this.loading = false;
        }
      });
    },
    // 获取顶级分类列表
    getTopList() {
      productCategoryTops().then((res) => {
        this.topList = res.data;
      });
    },
    handleResourceTip(type) {
      for (let item of this.resourceModelList) {
        if (type == item.value) {
          return item.label || "";
        }
      }
    },

    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        categorySort: 1,
        parentId: null,
        categoryName: null,
        categoryIcon: null,
        shelvedStatus: true,
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.getTopList();
      this.title = "添加";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.loading = true;
      this.reset();
      const id = row.categoryId || this.ids;
      productCategoryInfo(id).then((response) => {
        this.loading = false;
        this.form = response.data;
        this.open = true;
        this.title = "修改";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate((valid) => {
        if (valid) {
          if (!this.form.parentId) {
            this.form.parentId = 0;
          }
          this.buttonLoading = true;
          if (this.form.categoryId != null) {
            productCategoryEdit(this.form)
              .then((response) => {
                this.$modal.msgSuccess("修改成功");
                this.open = false;
                this.getList();
              })
              .finally(() => {
                this.buttonLoading = false;
              });
          } else {
            productCategoryAdd(this.form)
              .then((response) => {
                this.$modal.msgSuccess("新增成功");
                this.open = false;
                this.getList();
              })
              .finally(() => {
                this.buttonLoading = false;
              });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.categoryId;
      this.$modal
        .confirm('是否确认删除分类名称为"' + row.categoryName + '"的数据项？')
        .then(() => {
          this.loading = true;
          return productCategoryDel(ids);
        })
        .then(() => {
          this.loading = false;
          this.getList();
          this.$modal.msgSuccess("删除成功");
        })
        .finally(() => {
          this.loading = false;
        });
    },
    /** 上下架按钮操作 */
    setStatus(row) {
      const ids = row.categoryId;
      let statusText = row.shelvedStatus ? "下架" : "上架";
      this.$modal
        .confirm(
          "是否确认" +
          statusText +
          '分类名称为"' +
          row.categoryName +
          '"的数据项？'
        )
        .then(() => {
          this.loading = true;
          return productCategoryShelved(ids);
        })
        .then(() => {
          this.loading = false;
          this.getList();
          this.$modal.msgSuccess(statusText + "成功");
        })
        .finally(() => {
          this.loading = false;
        });
    },
  },
};
</script>
<style lang="scss">
.el-drawer__body {
  padding: 0 20px !important;
}
</style>
<style lang="scss" scoped>
.flex {
  display: flex;
}

.demo-drawer__footer {
  margin-left: 120px;
}

::v-deep .el-input.is-disabled .el-input__inner {
  background-color: #fff;
  color: rgb(96, 98, 102);
}
</style>
